# Copyright 2023 (c) Anna Schumaker.
"""The `xfstestsdb xunit rename` command."""
import argparse
import errno
import sys
from . import commands
from . import sqlite


class Command(commands.Command):
    """The `xfstestsdb xunit rename` command."""

    def __init__(self, subparser: argparse.Action,
                 sql: sqlite.Connection) -> None:
        """Set up the xunit rename command."""
        super().__init__(subparser, sql, "rename",
                         help="change the name for xfstests xunit file")
        self.parser.add_argument("runid", metavar="runid", nargs=1, type=int,
                                 help="runid of the xfstests run to change")
        self.parser.add_argument("old", metavar="old", nargs=1,
                                 help="old xunit name")
        self.parser.add_argument("new", metavar="new", nargs=1,
                                 help="new xunit name")

    def do_command(self, args: argparse.Namespace) -> None:
        """Rename an xunit entry in the xunits table."""
        if self.sql("SELECT name FROM xunits WHERE runid=? AND name=?",
                    args.runid[0], args.old[0]).fetchone() is None:
            print(f"error: either run #{args.runid[0]} or "
                  f"xunit '{args.old[0]}' do not exist", file=sys.stderr)
            sys.exit(errno.ENOENT)

        if args.new[0] == args.old[0]:
            return

        if self.sql("UPDATE xunits SET name=? WHERE runid=? AND name=?",
                    args.new[0], args.runid[0], args.old[0]) is None:
            print(f"error: run #{args.runid[0]} xunit "
                  f"'{args.new[0]}' already exists", file=sys.stderr)
            sys.exit(errno.EEXIST)

        print(f"renamed run #{args.runid[0]} xunit from "
              f"'{args.old[0]}' to '{args.new[0]}'")
